@@ -1,14 +1,15 @@
 import sys
 import typing
+import bpy.types
+
 from . import types
 from . import ops
 from . import utils
-from . import app
 from . import path
 from . import props
 from . import context
+from . import app
 
-context: 'types.Context' = None
-
-data: 'types.BlendData' = None
-'''Access to Blenders internal data '''
+data: 'bpy.types.BlendData' = None
+''' Access to Blender's internal data
+'''
