@@ -1,73 +1,113 @@
 import sys
 import typing
-from . import group
-from . import uv
-from . import paintcurve
-from . import image
-from . import wm
-from . import cloth
-from . import lattice
-from . import sketch
-from . import sculpt
-from . import lamp
-from . import boid
-from . import curve
-from . import poselib
-from . import camera
-from . import world
-from . import marker
-from . import safe_areas
-from . import nla
-from . import font
-from . import mball
-from . import texture
-from . import ptcache
-from . import buttons
-from . import view3d
-from . import view2d
-from . import script
-from . import gpencil
 from . import ui
-from . import import_curve
+from . import time
+from . import mask
+from . import import_scene
+from . import mball
+from . import file
+from . import buttons
+from . import cachefile
+from . import sound
+from . import info
+from . import texture
+from . import graph
 from . import ed
-from . import armature
-from . import constraint
+from . import console
 from . import export_mesh
 from . import dpaint
-from . import import_mesh
-from . import mesh
-from . import mask
-from . import action
-from . import import_scene
-from . import surface
-from . import rigidbody
-from . import pose
-from . import scene
-from . import screen
-from . import cycles
-from . import text
-from . import palette
-from . import sequencer
-from . import time
-from . import export_scene
-from . import anim
-from . import sound
-from . import transform
-from . import graph
-from . import cachefile
-from . import fluid
-from . import file
-from . import brush
-from . import info
-from . import paint
-from . import export_anim
-from . import outliner
-from . import import_anim
-from . import clip
+from . import wm
 from . import node
-from . import logic
-from . import particle
-from . import object
+from . import paint
+from . import import_anim
+from . import lamp
 from . import material
-from . import console
+from . import image
+from . import clip
+from . import screen
+from . import export_scene
+from . import particle
+from . import action
+from . import cycles
+from . import ptcache
+from . import mesh
+from . import gpencil
+from . import view3d
+from . import palette
+from . import scene
+from . import marker
+from . import sculpt
+from . import pose
+from . import outliner
+from . import anim
+from . import export_anim
+from . import fluid
+from . import import_mesh
+from . import transform
+from . import script
 from . import render
+from . import logic
+from . import camera
+from . import lattice
+from . import object
+from . import safe_areas
+from . import poselib
+from . import curve
+from . import surface
+from . import armature
+from . import rigidbody
+from . import boid
+from . import world
+from . import group
+from . import view2d
+from . import uv
+from . import text
+from . import sequencer
+from . import sketch
+from . import font
+from . import cloth
+from . import nla
+from . import brush
+from . import paintcurve
+from . import constraint
+from . import import_curve
+
+
+class BPyOps:
+    pass
+
+
+class BPyOpsSubMod:
+    pass
+
+
+class BPyOpsSubModOp:
+    def get_instance(self):
+        ''' 
+
+        '''
+        pass
+
+    def get_rna(self):
+        ''' 
+
+        '''
+        pass
+
+    def idname(self):
+        ''' 
+
+        '''
+        pass
+
+    def idname_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, args):
+        ''' 
+
+        '''
+        pass
